@@ -12,7 +12,7 @@
 #' the horizontal axes show lags in time units rather than seasonal units.
 #'
 #' The resulting tables from these functions can also be plotted using
-#' [`autoplot.tbl_cf()`].
+#' [`autoplot()`] with the methods provided by the ggtime package.
 #'
 # The tapered versions implement the ACF and PACF estimates and plots
 # described in Hyndman (2015), based on the banded and tapered estimates of
@@ -387,107 +387,3 @@ index_valid.cf_lag <- function(x) TRUE
 interval_pull.cf_lag <- function(x) {
   attr(x, "interval")
 }
-
-#' Auto- and Cross- Covariance and -Correlation plots
-#' 
-#' `r lifecycle::badge("deprecated")`
-#'
-#' `autoplot.tbl_cf()` was soft deprecated in feasts 0.4.2. Please use
-#' `ggtime::autoplot.tbl_cf()` instead. Produces a plot of impulse responses
-#' from an impulse response function.
-#'
-#' Produces an appropriate plot for the result of  [`ACF()`], [`PACF()`], or [`CCF()`].
-#'
-#' @param object A tbl_cf object (the result [`ACF()`], [`PACF()`], or [`CCF()`]).
-#' @param level The level of confidence for the blue dashed lines.
-#' @param ... Unused.
-#'
-#' @return A ggplot object showing the correlations.
-#'
-#' @importFrom ggplot2 ggplot geom_hline xlab ylab ggtitle vars
-#' @importFrom stats qnorm
-#' @export
-autoplot.tbl_cf <- function(object, level = 95, ...){
-  cf_type <- colnames(object)[colnames(object) %in% c("acf", "pacf", "ccf")]
-  plot_aes <- ggplot2::aes(
-    x = !!sym("lag"),
-    y = !!sym(cf_type)
-  )
-  interval <- interval(object)
-
-  if(length(level) > 1){
-    abort("Only one confidence interval is currently supported for this autoplot.")
-  }
-
-  itvl_fmt <- utils::getS3method("format", "interval", envir = getNamespace("tsibble"))
-  p <- ggplot(object, plot_aes) +
-    ggplot2::geom_segment(aes(xend = !!sym("lag"), yend = 0)) +
-    geom_hline(yintercept = 0) +
-    xlab(paste0("lag [", itvl_fmt(interval),"]"))
-
-  if(!is.null(level)){
-    conf_int <- object%@%"num_obs" %>%
-      mutate(
-        upper = qnorm((1 + (level/100)) / 2) / sqrt(!!sym(".len")),
-        lower = !!parse_expr("-upper")
-      ) %>%
-      gather("type", ".ci", !!!syms(c("upper", "lower")))
-    p <- p + geom_hline(aes(yintercept = !!sym(".ci"), group = !!sym("type")),
-                        data = conf_int, colour = "blue", linetype = "dashed")
-  }
-
-  if(n_keys(object) > 1){
-    p <- p + facet_grid(rows = vars(!!!key(object)))
-  }
-
-  p
-}
-
-#' @importFrom ggplot2 scale_type
-#' @export
-scale_type.cf_lag <- function(x) c("cf_lag", "continuous")
-
-#' lagged datetime scales
-#' This set of scales defines new scales for lagged time structures.
-#'
-#' @param ... Further arguments to be passed on to scale_x_continuous()
-#'
-#' @return A ggproto object inheriting from `Scale`
-#'
-#' @keywords internal
-#' @name scale_cf_lag
-#' @rdname scale_cf_lag
-#' @export
-scale_x_cf_lag <- function(...) {
-  scale <- ggplot2::ggproto("ScaleContinuousLag", ggplot2::scale_x_continuous(...),
-                   train = function (self, x){
-                     if (length(x) == 0)
-                       return()
-                     self$range$train(vctrs::vec_data(x))
-                     if(!is.null(gap <- attr(x, "interval"))){
-                       self$interval <- gap
-                       freq <- get_frequencies(NULL, gap, .auto = "all")
-                       self$frequency <- min(freq[freq>3]%empty%NA)
-                     }
-                   },
-                   get_breaks = function(self, limits = self$get_limits()) {
-                     if(inherits(self$breaks, "waiver") && !is.na(self$frequency)){
-                       freq <- self$frequency
-                       lags <- ceiling(limits[1]):floor(limits[2])
-                       # nlags <- length(lags)
-                       # np <- nlags / freq
-                       self$breaks <- lags[lags%%(freq/2)==0]
-                     }
-                     ggplot2::ggproto_parent(ggplot2::ScaleContinuous, self)$get_breaks()
-                   },
-                   get_labels = function(self, breaks = self$get_breaks()){
-                     # if(inherits(self$labels, "waiver")){
-                     #   interval_type <- map_lgl(self$interval, ~.x!=0)
-                     #   self$labels <- breaks
-                     #   #suffix <- toupper(names(self$interval)[interval_type])
-                     #   #self$labels <- paste(breaks*as.numeric(self$interval[interval_type]), paste0(suffix, ifelse(breaks!=0, "S", "")))
-                     # }
-                     ggplot2::ggproto_parent(ggplot2::ScaleContinuous, self)$get_labels()
-                   })
-  scale
-}
