@@ -6,14 +6,6 @@ add_class <- function(x, new_class){
   if (is.null(x)) y else x
 }
 
-require_package <- function(pkg){
-  if(!requireNamespace(pkg, quietly = TRUE)){
-    abort(
-      sprintf('The `%s` package must be installed to use this functionality. It can be installed with install.packages("%s")', pkg, pkg)
-    )
-  }
-}
-
 `%empty%` <- function(x, y) {
   if (length(x) == 0) y else x
 }
